((((((function () {
  var a;
  if (b) return;
  a = (new c);
  return a;
})())(function () {
  var a;
  if (b) return;
  a = (new c);
  return a;
}))())(function () {
  var a;
  if (b) return;
  a = (new c);
  return a;
}))());
