((function () {
  b: {
    if (a) break b;
    c: {
      if (a) break c;
      if (a) break c;
      if (a) break c;
    }
    c: {
      if (a) break c;
      if (a) break c;
      if (a) break c;
    }
  }
})());
